@@ -1,6 +1,12 @@
 package Vmprobe::Cache;
 
+use common::sense;
+
 require XSLoader;
 XSLoader::load;
 
+
+our $locks = {};
+
+
 1;
