@@ -50,11 +50,6 @@ sub add_remote {
         $self->{resources}->{$resource_id}->on_init_remote($remote);
     }
 
-    $remote->probe('version', {}, sub {
-        my ($version) = @_;
-        $remote->add_version_info($version);
-    });
-
     return $remote;
 }
 
@@ -80,6 +75,8 @@ sub remove_remote {
     }
 
     splice(@{ $self->{remotes} }, $position, 1);
+
+    $remote->shutdown;
 }
 
 
