@@ -4,8 +4,9 @@ use common::sense;
 
 use parent 'Vmprobe::Resource::Base::AllRemotes';
 
+use Vmprobe::Util;
+
 use Time::HiRes;
-use Sereal::Encoder;
 use Guard;
 
 
@@ -97,13 +98,13 @@ sub cmd_lock_sel {
           num_pages => $args->{num_pages},
         },
         sub {
-            my ($res) = @_;
+            my ($res, $connection_id) = @_;
             undef $job;
 
             my $lock_id = $res->{lock_id};
 
             $self->{locks}->{$lock_id} = guard {
-                $remote->probe('cache::unlock', { lock_id => $lock_id, }, sub {});
+                $remote->probe('cache::unlock', { lock_id => $lock_id, }, sub {}, $connection_id);
             };
 
             $self->update({
@@ -170,7 +171,7 @@ sub cmd_take_snapshot {
 
             open(my $fh, '>:raw', $filename) || die "couldn't open $filename for writing: $!";
 
-            print $fh Sereal::Encoder::encode_sereal($data, { compress => 1, });
+            print $fh sereal_encode($data);
         }
     );
 }
